import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
export declare type RadioButtonGroupOption = PropsWithMetadata<{
    value: string | number;
    label?: string;
    id?: string;
    disabled?: boolean;
    subLabel?: string;
    className?: string;
}>;
export declare type RadioButtonGroupProps = PropsWithMetadata<{
    /** Applies a class name to the root element */
    className?: string;
    /** The name to apply to every Radio Button in the group. A name is generated if none is specified */
    name?: string;
    /** Disables every Radio Button in the group */
    disabled?: boolean;
    /** Sets the orientation of the Radio Button group */
    orientation?: 'vertical' | 'horizontal';
    /** Array of options to render as Radio Button components */
    options: RadioButtonGroupOption[];
    /** The current selected options value */
    value?: RadioButtonGroupOption['value'];
    /** Gets called each time an option is checked. The only argument of this callback is an
     * array of CheckboxGroupOption
     */
    onChange?: (option: RadioButtonGroupOption) => void;
}>;
declare const RadioButtonGroup: React.ForwardRefExoticComponent<{
    /** Applies a class name to the root element */
    className?: string | undefined;
    /** The name to apply to every Radio Button in the group. A name is generated if none is specified */
    name?: string | undefined;
    /** Disables every Radio Button in the group */
    disabled?: boolean | undefined;
    /** Sets the orientation of the Radio Button group */
    orientation?: "vertical" | "horizontal" | undefined;
    /** Array of options to render as Radio Button components */
    options: RadioButtonGroupOption[];
    /** The current selected options value */
    value?: string | number | undefined;
    /** Gets called each time an option is checked. The only argument of this callback is an
     * array of CheckboxGroupOption
     */
    onChange?: ((option: RadioButtonGroupOption) => void) | undefined;
} & {
    metadata?: import("@highlight-ui/utils-commons").ComponentMetadata | undefined;
} & React.RefAttributes<HTMLDivElement>>;
export default RadioButtonGroup;
